@@ -1,10 +1,8 @@
-import datetime
-import itertools
 import json
 import os
 import re
 from abc import ABC, abstractmethod
-from datetime import timedelta
+from datetime import timedelta, datetime
 
 import humanfriendly
 from typing import (
@@ -41,14 +39,31 @@ class HTCondorAccountingItem:
     exit_code: int
     status: Job.Status
 
-    def __init__(self, job_id: int, status: Job.Status, exit_code: int):
+    start_date: datetime
+    completion_date: datetime
+
+    def __init__(
+        self,
+        job_id: int,
+        status: Job.Status,
+        exit_code: int,
+        start_date: datetime,
+        completion_date: datetime,
+    ):
         self.job_id = job_id
         self.status = status
         self.exit_code = exit_code
+        self.start_date = start_date
+        self.completion_date = completion_date
 
     @classmethod
     def from_parts(
-        cls, job_id: int, condor_status: int, exit_code: int
+        cls,
+        job_id: int,
+        condor_status: int,
+        exit_code: int,
+        start_date: int,
+        completion_date: int,
     ) -> "HTCondorAccountingItem":
         # see http://pages.cs.wisc.edu/~adesmet/status.html
 
@@ -80,7 +95,13 @@ class HTCondorAccountingItem:
             # at scheduler level, this is completed, might have exited with failure though
             if exit_code != 0 and exit_code != -1:
                 status = Job.Status.FAILED
-        return cls(job_id, status, exit_code)
+        return cls(
+            job_id,
+            status,
+            exit_code,
+            datetime.utcfromtimestamp(start_date),
+            datetime.utcfromtimestamp(completion_date),
+        )
 
     def __repr__(self) -> str:
         return f"HTCondorAI<{self.job_id}, {repr(self.status)}, {self.exit_code}>"
@@ -135,16 +156,39 @@ class ShellHTCondorInterface(HTCondorInterface):
         data = json.loads(output)
         for item in data:
             job_id = item["ClusterId"]
-            assert item["ProcId"] == 0, "Clusters with more than one jobs not supported"
+            if item["ProcId"] != 0:
+                logger.info(
+                    "ProcId = %d, Clusters with more than one job not supported, skipping",
+                    item["ProcId"],
+                )
+                continue
             condor_status = item["JobStatus"]
             exit_code = item["ExitCode"] if "ExitCode" in item else -1
-            yield HTCondorAccountingItem.from_parts(job_id, condor_status, exit_code)
+            yield HTCondorAccountingItem.from_parts(
+                job_id,
+                condor_status,
+                exit_code,
+                item.get("JobCurrentStartDate", 0),
+                item.get("CompletionDate", 0),
+            )
 
     def condor_q(self) -> Iterator[HTCondorAccountingItem]:
 
         logger.debug("Getting job infos")
 
-        args = ["-attributes", ",".join(["ClusterId", "ProcId", "JobStatus"]), "-json"]
+        args = [
+            "-attributes",
+            ",".join(
+                [
+                    "ClusterId",
+                    "ProcId",
+                    "JobStatus",
+                    "JobCurrentStartDate",
+                    "CompletionDate",
+                ]
+            ),
+            "-json",
+        ]
 
         assert self._condor_q is not None
         return self._parse_output(str(self._condor_q(*args)))
@@ -163,7 +207,16 @@ class ShellHTCondorInterface(HTCondorInterface):
             "-userlog",
             log_file,
             "-attributes",
-            ",".join(["ClusterId", "ProcId", "JobStatus", "ExitCode"]),
+            ",".join(
+                [
+                    "ClusterId",
+                    "ProcId",
+                    "JobStatus",
+                    "ExitCode",
+                    "JobCurrentStartDate",
+                    "CompletionDate",
+                ]
+            ),
             "-json",
             "-limit",
             "10000",
@@ -199,18 +252,27 @@ export HTCONDOR_CLUSTER_ID=$(grep "^ClusterId" $_CONDOR_JOB_AD | cut -d= - -f2 |
 mkdir -p $KONG_JOB_SCRATCHDIR
 
 stdout={{stdout}}
+echo "Job start: $(date)" > $stdout
 
 ({{command}}) > $stdout 2>&1
 """.strip()
 
 batchfile_tpl_str = """
-universe = vanilla
 log = {{htcondor_out}}
 executable = {{jobscript}}
+{%- if universe is not none %}
+universe = {{universe}}
+{%- endif %}
+{%- if cores > 1 %}
 request_cpus = {{cores}}
+{%- endif %}
+{%- if memory > 0 %}
 request_memory = {{memory}}
+{%- endif %}
 batch_name = {{name}}
+{%- if walltime is not none %}
 +MaxRuntime = {{walltime}}
+{%- endif %}
 
 {{submitfile_extra}}
 
@@ -251,10 +313,10 @@ class HTCondorDriver(BatchDriverBase):
         folder: "Folder",
         command: str,
         cores: int = 1,
-        memory: int = 2000,
+        memory: int = 0,
         universe: Optional[str] = None,
         name: Optional[str] = None,
-        walltime: Union[timedelta, str] = timedelta(minutes=30),
+        walltime: Optional[Union[timedelta, str]] = timedelta(minutes=30),
     ) -> "Job":  # type: ignore
 
         if universe is None:
@@ -284,8 +346,13 @@ class HTCondorDriver(BatchDriverBase):
         batchfile = os.path.join(log_dir, "batchfile.sh")
         jobscript = os.path.join(log_dir, "jobscript.sh")
 
-        if isinstance(walltime, str):
-            norm_walltime = int(parse_timedelta(walltime).total_seconds())
+        if walltime is None:
+            norm_walltime = None
+        elif isinstance(walltime, str):
+            if walltime == "None":
+                norm_walltime = None
+            else:
+                norm_walltime = int(parse_timedelta(walltime).total_seconds())
         elif isinstance(walltime, timedelta):
             norm_walltime = int(walltime.total_seconds())
         else:
@@ -342,24 +409,32 @@ class HTCondorDriver(BatchDriverBase):
         for job in jobs:
             self._check_driver(job)
 
-        now = datetime.datetime.utcnow()
+        epoch = datetime.utcfromtimestamp(0)
+
+        item_map = {item.job_id: item for item in self.htcondor.condor_q()}
+        # only add history info if we didn't have info in queue
+        for item in self.htcondor.condor_history(self.log_file):
+            if item.job_id not in item_map:
+                item_map[item.job_id] = item
 
         def proc() -> Iterable[Job]:
             job_not_found = 0
-            for item in itertools.chain(
-                self.htcondor.condor_q(), self.htcondor.condor_history(self.log_file)
-            ):
+            for item in item_map.values():
                 job = Job.get_or_none(batch_job_id=item.job_id)
                 if job is None:
                     job_not_found += 1
                     continue
                 job.status = item.status
                 job.data["exit_code"] = item.exit_code
-                job.updated_at = now
+
+                updated_at = max([item.start_date, item.completion_date])
+                if updated_at == epoch:
+                    updated_at = job.created_at
+                job.updated_at = updated_at
                 yield job
             if job_not_found > 0:
-                logger.warning(
-                    "Tried to fetch %d slurm jobs which where not found in the database",
+                logger.debug(
+                    "Tried to fetch %d htcondor jobs which where not found in the database",
                     job_not_found,
                 )
 
