@@ -22,7 +22,7 @@ from click import style
 from kong.model.job import color_dict
 from .table import format_table
 
-from .util import shorten_path, Spinner
+from .util import shorten_path, Spinner, set_verbosity
 from .state import DoesNotExist
 from .config import APP_NAME, APP_DIR
 from .logger import logger
@@ -102,7 +102,7 @@ class Repl(cmd.Cmd):
         self, text: str, line: str, begidx: int, endidx: int
     ) -> List[str]:
         logger.debug(
-            "text: %s, line: %s, begidx: %d, endidx: %d", text, line, begidx, endidx,
+            "text: %s, line: %s, begidx: %d, endidx: %d", text, line, begidx, endidx
         )
 
         # find component
@@ -162,6 +162,14 @@ class Repl(cmd.Cmd):
         type=click.Choice([s.name for s in Job.Status]),
         help="Only list jobs with this status. Will still show other jobs in folder summaries",
     )
+    @click.option(
+        "--extra",
+        "-e",
+        "extra_columns",
+        type=str,
+        default="",
+        help="Additional columns to grab from jobs' data dict. Comma separated list.",
+    )
     def do_ls(
         self,
         dir: str,
@@ -169,6 +177,7 @@ class Repl(cmd.Cmd):
         recursive: bool,
         show_sizes: bool,
         status_filter_str: Optional[str],
+        extra_columns: str,
     ) -> None:
         "List the directory content of DIR: jobs and folders"
         try:
@@ -178,6 +187,12 @@ class Repl(cmd.Cmd):
 
             folders, jobs = self.state.ls(dir, refresh=refresh)
 
+            _extra_columns = extra_columns.split(",") if extra_columns != "" else []
+
+            _extra_columns = self.state.config.repl_extra_columns + _extra_columns
+
+            logger.debug("Extra columns: %s", _extra_columns)
+
             if recursive:
                 arg_folder = Folder.find_by_path(dir, self.state.cwd)
                 assert arg_folder is not None  # should be a folder
@@ -259,6 +274,10 @@ class Repl(cmd.Cmd):
                         headers.append("output size")
                         align.append("l")
 
+                    for col in _extra_columns:
+                        headers.append(col)
+                        align.append("l")
+
                     headers += ["batch job id", "created", "updated", "status"]
                     align += ["r+", "l", "l", "l"]
 
@@ -298,6 +317,9 @@ class Repl(cmd.Cmd):
                         else:
                             updated_at_str = updated_at.strftime(dtfmt)
 
+                        for col in _extra_columns:
+                            row.append(job.data.get(col, "-"))
+
                         row += [
                             batch_job_id,
                             created_at.strftime(dtfmt),
@@ -708,6 +730,16 @@ class Repl(cmd.Cmd):
             update_interval=update_interval,
         )
 
+    @parse_arguments
+    @click.argument("verbosity", type=int)
+    def do_set_verbosity(self, verbosity: int) -> None:
+        """
+        Set verbosity level to VERBOSITY
+        """
+        if verbosity < 0:
+            raise ValueError("Verbosity must be >= 0")
+        set_verbosity(verbosity)
+
     def do_shell(self, cmd: str) -> None:
         """
         Run the command given in a shell.
